# Generated by roxygen2: do not edit by hand

S3method(print,devianlm)
export(devianlm_stats)
export(get_devianlm_threshold)
import(parallel)
importFrom(Rcpp,sourceCpp)
importFrom(stats,.lm.fit)
importFrom(stats,complete.cases)
importFrom(stats,lm.influence)
importFrom(stats,quantile)
importFrom(stats,rnorm)
useDynLib(devianLM, .registration = TRUE)
