#' @export
print.devianlm <- function(x, ...) {
  cat("devianLM results\n")
  cat("----------------\n")
  cat("Number of observations:", length(x$reg_residuals), "\n")
  cat("Number of detected outliers:", length(x$outliers), "\n")
  cat("Threshold:", format(x$threshold, digits = 4), "\n")
  cat("\nUse `$` to access full results.\n")
  
  invisible(x)
}