# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

devianlm_cpp <- function(X, n_sims, nthreads) {
    .Call(`_devianLM_devianlm_cpp`, X, n_sims, nthreads)
}

