#' devianLM: Outlier detection via studentized residuals
#' 
#' Provides a method to detect values poorly explained by a Gaussian linear model. 
#' The procedure is based on the maximum of the absolute value of the studentized 
#' residuals (conditional on the design matrix), which is a parameter-free 
#' statistic. This approach generalizes several procedures used to detect 
#' abnormal values during longitudinal monitoring of biological markers.
#' @details
#' The main R functions are:
#' \itemize{
#'   \item \code{\link{get_devianlm_threshold}}: computes the threshold via Monte-Carlo simulations.
#'   \item \code{\link{devianlm_stats}}: identifies outliers based on this threshold. 
#'   It is also possible to use a custom threshold value, specified by the user.
#' }
#'
#' Monte Carlo simulations are parallelized using OpenMP when available.
#'
#' @references
#' Sauliere, G., Berthelot, G., and Dedecker, J. (2025) \emph{DEViaN-LM An R 
#' Package for Detecting Abnormal Values in the Gaussian Linear Model}. 
#' https://doi.org/10.48550/arXiv.2509.02202
#' \doi{10.48550/arXiv.2509.02202}
#'
#' Berthelot G., Gelein B., Meinadier E. Orhant E., Dedecker J., (2025) 
#' \emph{Z-scores-based methods and their application to 
#' biological monitoring: An extended analysis of professional soccer players 
#' and cyclists athletes}. https://arxiv.org/abs/2510.01810
#' \doi{10.48550/arXiv.2510.01810}
#'
"_PACKAGE"

